@@ -131,6 +131,7 @@ class DbndKubernetesScheduler(AirflowKubernetesScheduler):
         self.current_resource_version = 0
         self.kube_watcher = self._make_kube_watcher_dbnd()
         # will be used to low level pod interactions
+        self.failed_pods_to_ignore = []
         self.running_pods = {}
         self.pod_to_task = {}
         self.metrics_logger = KubernetesMetricsLogger()
@@ -216,12 +217,28 @@ class DbndKubernetesScheduler(AirflowKubernetesScheduler):
         self.metrics_logger.log_pod_started(task_run.task)
 
     def delete_pod(self, pod_id):
-        self.running_pods.pop(pod_id, None)
-        result = self.kube_dbnd.delete_pod(pod_id, self.namespace)
+        if pod_id in self.failed_pods_to_ignore:
+            logger.warning(
+                "Received request to delete pod %s that is ignored! Ignoring...", pod_id
+            )
+            return
+        try:
+            found_pod = self.running_pods.pop(pod_id, None)
+            if found_pod:
+                result = self.kube_dbnd.delete_pod(pod_id, self.namespace)
 
-        self.metrics_logger.log_pod_deleted(self.pod_to_task[pod_id])
-        self.pod_to_task.pop(pod_id)  # Keep the cache clean
-        return result
+                if pod_id in self.pod_to_task:
+                    self.metrics_logger.log_pod_deleted(self.pod_to_task[pod_id])
+                    self.pod_to_task.pop(pod_id)  # Keep the cache clean
+
+                return result
+        except Exception as e:
+            # Catch all exceptions to prevent any delete loops, best effort
+            logger.warning(
+                "Exception raised when trying to delete pod %s! Adding to ignored list...",
+                pod_id,
+            )
+            self.failed_pods_to_ignore.append(pod_id)
 
     def terminate(self):
         pods_to_delete = sorted(self.running_pods.keys())
